package com.rjconsultores.ventaboletos.web.gui.controladores.esquemaoperacional;

import java.util.List;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.context.annotation.Scope;
import org.springframework.stereotype.Controller;
import org.zkoss.util.resource.Labels;
import org.zkoss.zhtml.Messagebox;
import org.zkoss.zk.ui.Component;
import org.zkoss.zk.ui.Executions;
import org.zkoss.zk.ui.event.Event;

import com.rjconsultores.ventaboletos.entidad.AliasServico;
import com.rjconsultores.ventaboletos.entidad.ClaseServicio;
import com.rjconsultores.ventaboletos.entidad.Empresa;
import com.rjconsultores.ventaboletos.entidad.OrgaoConcedente;
import com.rjconsultores.ventaboletos.exception.BusinessException;
import com.rjconsultores.ventaboletos.service.AliasServicoService;
import com.rjconsultores.ventaboletos.service.ClaseServicioService;
import com.rjconsultores.ventaboletos.service.OrgaoConcedenteService;
import com.rjconsultores.ventaboletos.utilerias.UsuarioLogado;
import com.rjconsultores.ventaboletos.web.utilerias.MyComboboxEstandar;
import com.rjconsultores.ventaboletos.web.utilerias.MyGenericForwardComposer;
import com.rjconsultores.ventaboletos.web.utilerias.MyListbox;

@Controller("editarAliasClasseController")
@Scope("prototype")
public class EditarAliasClasseController extends MyGenericForwardComposer {

	private static final String TITULO = "editarAliasClasseController.window.title";
	private static final long serialVersionUID = 1L;
	@Autowired
	private AliasServicoService aliasClasseService;
	@Autowired
	private ClaseServicioService claseServicioService;
	@Autowired
	private OrgaoConcedenteService orgaoConcedenteService;

	private AliasServico aliasClasse;
	private MyListbox aliasClasseList;
	
	private List<ClaseServicio> lsClasse;
	private List<OrgaoConcedente> lsOrgaoConcedente;
	
	private MyComboboxEstandar cmbClasse;
	private MyComboboxEstandar cmbAlias;
	private MyComboboxEstandar cmbOrgaoConcedente;
	

	@Override
	public void doAfterCompose(Component comp) throws Exception {
		List<Empresa> lsEmpresa = UsuarioLogado.getUsuarioLogado().getEmpresa();
		List<ClaseServicio> lsClasse = claseServicioService.buscarTodosExceto(-1);
		setLsOrgaoConcedente(orgaoConcedenteService.obtenerTodos());
		
		super.doAfterCompose(comp);
		
		AliasServico aliasClasse = (AliasServico) Executions.getCurrent().getArg().get("aliasClasse");
		aliasClasseList = (MyListbox) Executions.getCurrent().getArg().get("aliasClasseList");
	}

	public void onClick$btnSalvar(Event ev) throws InterruptedException {
		
		try {
			
			aliasClasseService.suscribirActualizar(aliasClasse);
			aliasClasseList.updateItem(aliasClasse);

			Messagebox.show(
					Labels.getLabel("editarAliasClasseController.MSG.suscribirOK"),
					Labels.getLabel(TITULO),
					Messagebox.OK, Messagebox.INFORMATION);

			closeWindow();
		} catch (BusinessException ex) {
			Messagebox.show(
					ex.getMessage(),
					Labels.getLabel(TITULO),
					Messagebox.OK, Messagebox.ERROR);
		} catch (Exception ex) {
			Messagebox.show(
						Labels.getLabel("MSG.Error"),
						Labels.getLabel(TITULO),
						Messagebox.OK, Messagebox.ERROR);
		}
	}

	public void onClick$btnApagar(Event ev) throws InterruptedException {
		Integer resp = Messagebox.show(
					Labels.getLabel("editarAliasClasseController.MSG.borrarPergunta"),
					Labels.getLabel(TITULO),
					Messagebox.YES | Messagebox.NO, Messagebox.QUESTION);

		if (resp == Messagebox.YES) {

			aliasClasseService.borrar(aliasClasse);

			Messagebox.show(
						Labels.getLabel("editarAliasClasseController.MSG.borrarOK"),
						Labels.getLabel(TITULO),
						Messagebox.OK, Messagebox.INFORMATION);

			aliasClasseList.removeItem(aliasClasse);

			closeWindow();
		}
	}

	public List<ClaseServicio> getLsClasse() {
		return lsClasse;
	}

	public void setLsClasse(List<ClaseServicio> lsClasse) {
		this.lsClasse = lsClasse;
	}

	public List<OrgaoConcedente> getLsOrgaoConcedente() {
		return lsOrgaoConcedente;
	}

	public void setLsOrgaoConcedente(List<OrgaoConcedente> lsOrgaoConcedente) {
		this.lsOrgaoConcedente = lsOrgaoConcedente;
	}

	public MyComboboxEstandar getCmbClasse() {
		return cmbClasse;
	}

	public void setCmbClasse(MyComboboxEstandar cmbClasse) {
		this.cmbClasse = cmbClasse;
	}

	public MyComboboxEstandar getCmbAlias() {
		return cmbAlias;
	}

	public void setCmbAlias(MyComboboxEstandar cmbAlias) {
		this.cmbAlias = cmbAlias;
	}

	public MyComboboxEstandar getCmbOrgaoConcedente() {
		return cmbOrgaoConcedente;
	}

	public void setCmbOrgaoConcedente(MyComboboxEstandar cmbOrgaoConcedente) {
		this.cmbOrgaoConcedente = cmbOrgaoConcedente;
	}
}
